@@ -87,15 +87,5 @@ fi
 # End automatically added section
 
 
-if [ -x "/etc/init.d/benno-rest" ]; then
-    update-rc.d benno-rest defaults >/dev/null
-    if [ -x "`which invoke-rc.d 2>/dev/null`" ]; then
-        invoke-rc.d benno-rest start || exit $?
-    else
-        /etc/init.d/benno-rest start || exit $?
-    fi
-fi
-
-
 exit 0
 
